OD_Settings = {
	MiniMapX = 0,
	MiniMapY = 0,
	Enabled = true,
	Hide = true,
	Aggro = true,
	Override = false,
	Overridden = false
}
OD_Fighting = false
OD_Dragx = 0
OD_Dragy = 0

local function print(msg)
	DEFAULT_CHAT_FRAME:AddMessage("Auto Objectives Display : " .. tostring(msg))
end

function OD_checkStatusForCollapse()

	-- hide on aggro
	if (OD_Fighting == true and OD_Settings.Aggro == true) then
		ObjectiveTracker_Collapse()
		if (OD_Settings.Hide == true) then
			ObjectiveTrackerFrame:Hide()
		end
		return
	end

	if (IsInInstance()) then -- hide in instance
		ObjectiveTracker_Collapse()
		if (OD_Settings.Hide == true) then
			ObjectiveTrackerFrame:Hide()
		end
	elseif (OD_Settings.Overridden == false) then -- if not forced hidden, then we must be showing
		ObjectiveTracker_Expand()
		ObjectiveTrackerFrame:Show()
	end
end

function OD_ObjectivesDisplayFrame_OnEvent(self,event,...)

	if (event == "VARIABLES_LOADED") then
		OD_Set_MiniMap()
		print("Version 1.2")
	elseif (OD_Settings.Enabled == true) then
		if event == "RAID_TARGET_UPDATE" then
			C_Timer.After(2,OD_checkStatusForCollapse)
		elseif event == "PLAYER_ENTERING_WORLD" then
			C_Timer.After(2,OD_checkStatusForCollapse)
		elseif event == "PLAYER_REGEN_ENABLED" then
			OD_Fighting = false
			OD_checkStatusForCollapse()
		elseif event == "PLAYER_REGEN_DISABLED" then
			OD_Fighting = true
			OD_checkStatusForCollapse()
		end
	end
end

function OD_ObjectivesDisplay_Command(Msg,Editbox)

	if Msg then 
		Msg=strlower(Msg)
	end
	
	if Msg == "help" or Msg == "?" then
		print("Use /ODISP [on/off/show/hide].")
		print("On/off to enable or disable automatic hiding.")
		print("Show/hide to completely show or hide the objectives list frame.")
	elseif Msg == "on" then
		OD_Settings.Enabled = true
		OD_checkStatusForCollapse()
		OD_CheckButtonOn:SetChecked(true)
	elseif Msg == "off" then
		OD_Settings.Enabled = false
		ObjectiveTracker_Expand()
		ObjectiveTrackerFrame:Show()
		OD_CheckButtonOn:SetChecked(false)
	elseif Msg == "show" then
		ObjectiveTrackerFrame:Show()
		ObjectiveTracker_Expand()
	elseif Msg == "hide" then
		ObjectiveTrackerFrame:Hide()
	end
end

function OD_ObjectivesDisplayConfigFrame_OnLoad(panel)

	SlashCmdList["ObjectivesDisplay"] = OD_ObjectivesDisplay_Command
	SLASH_ObjectivesDisplay1 ="/ODISP"
	
	panel:RegisterEvent("VARIABLES_LOADED")
	panel:RegisterEvent("PLAYER_ENTERING_WORLD")
	panel:RegisterEvent("RAID_TARGET_UPDATE")
	panel:RegisterEvent("PLAYER_REGEN_ENABLED")
	panel:RegisterEvent("PLAYER_REGEN_DISABLED")
	panel:SetScript("OnEvent", OD_ObjectivesDisplayFrame_OnEvent)
	
	panel.name = "Objectives Manager" ;
    InterfaceOptions_AddCategory(panel);
end

-- reflect the settings for the settings dialog
function OD_ObjectivesDisplayConfigFrame_OnShow()
	OD_CheckButtonOn:SetChecked(OD_Settings.Enabled == true)
	OD_CheckButtonHide:SetChecked(OD_Settings.Hide == true)
	OD_CheckButtonAggro:SetChecked(OD_Settings.Aggro == true)
	OD_CheckButtonOverride:SetChecked(OD_Settings.Override == true)
end

-- is the addon enabled?
function OD_ObjectivesShowConfigFrame_toggleEnable()
	if (OD_Settings.Enabled == true) then
		OD_ObjectivesDisplay_Command("off")
	else
		OD_ObjectivesDisplay_Command("on")
	end
end

-- are we hiding the objectives?
function OD_ObjectivesShowConfigFrame_toggleHide()
	OD_Settings.Hide = not OD_Settings.Hide
end

-- hide when fighting?
function OD_ObjectivesShowConfigFrame_toggleFight()
	OD_Settings.Aggro = not OD_Settings.Aggro
end

-- icon override being used?
function OD_ObjectivesShowConfigFrame_toggleOverride()
	OD_Settings.Override = not OD_Settings.Override
end

function OD_MinimapButton_DraggingFrame_Start()
	OD_Dragx,OD_Dragy = GetCursorPosition()
	OD_Dragx = OD_Dragx - OD_Settings.MiniMapX
	OD_Dragy = OD_Dragy - OD_Settings.MiniMapY
end

function OD_MinimapButton_DraggingFrame_OnUpdate()

	local xpos,ypos = GetCursorPosition()

	xpos = (xpos - OD_Dragx)
	ypos = (ypos - OD_Dragy)
	
	OD_Settings.MiniMapX = xpos
	OD_Settings.MiniMapY = ypos

	OD_Set_MiniMap()
end

function OD_Set_MiniMap()
	local left, bottom, width, height = Minimap:GetRect()

	height = height + 32 -- allows us to place it below the map
	
	if (OD_Settings.MiniMapX < 0) then OD_Settings.MiniMapX = 0 
	elseif (OD_Settings.MiniMapX > width) then OD_Settings.MiniMapX = width end
	if (OD_Settings.MiniMapY > 0) then OD_Settings.MiniMapY = 0 
	elseif (OD_Settings.MiniMapY < (0-height)) then OD_Settings.MiniMapY = (0-height) end

	OD_MinimapButton:SetPoint("TOPLEFT","Minimap","TOPLEFT",OD_Settings.MiniMapX,OD_Settings.MiniMapY)
end

function OD_MinimapButton_OnClick()
	local button =  GetMouseButtonClicked() 

	if (button == "LeftButton") then
		if not (ObjectiveTrackerFrame:IsVisible()) then
			OD_Settings.Overridden = false -- only override when hiding, so back to auto
			ObjectiveTrackerFrame:Show()
			if (ObjectiveTrackerFrame.collapsed) then
				ObjectiveTracker_Expand()
			end
		else
			if (OD_Settings.Override == true) then
				OD_Settings.Overridden = true
			end
			ObjectiveTrackerFrame:Hide()
		end
		
	else
		 InterfaceOptionsFrame_OpenToCategory(OD_ObjectivesDisplayConfigFrame);
		 InterfaceOptionsFrame_OpenToCategory(OD_ObjectivesDisplayConfigFrame);
	end
end

function OD_MinimapButton_OnEnter(self)
	local txt = "|cFFff8844Objectives Display\r\n|cFF008844Click me to toggle the Objectives display\r\n|cFF884444Right click for options"
	
	if (OD_Settings.Override == true) then
		txt = txt .. "\r\n\r\n|cFFFFFFFFOverride enabled, once hidden by right clicking, the Objectives will stay hidden until you click this icon again"
	end
	
	GameTooltip:SetOwner(self or UIParent, "ANCHOR_LEFT")
	GameTooltip:SetText( txt )
	GameTooltip:Show()
end

function OD_MinimapButton_OnLeave(self)
  GameTooltip:Hide()
end

function OD_MinimapButton_OnLoad(self)
	self:RegisterForClicks("LeftButtonUp","RightButtonUp")
	self:RegisterForDrag("LeftButton","RightButton")
end





